.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. TotalDepth introduction

.. _TotalDepth-intro:

###############################
Introduction to TotalDepth
###############################

TotalDepth is an Open Source, cross platform, software collection that can process petrophysical data from the oil field such as wireline logs, seismic data and so on.

Conventional, proprietary, software for petrophysical data tends to be expensive to licence, restrictive, slow to develop for and tied to expensive hardware. TotalDepth changes all of that. 

TotalDepth is open and cross-platform, and produces results straight to the bowser. TotalDepth supports such technologies such as HTML5, AJAX, Software as a Service (SaaS) and Cloud Computing.

**********************
Software Technology
**********************

For rapid development and performance TotalDepth is written in `Python <http://www.python.org>`_ with performance critical code written in C/C++ or `Cython <http://www.cython.org>`_.

TotalDepth was developed using :abbr:`TDD (Test Driven Development)` in an agile fashion using *nano-iterations*.
